@@ -24,7 +24,7 @@ class DataSource(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not self._source:
                 raise MissingRequiredArgumentError(argument="source")
 
