@@ -43,7 +43,7 @@ class Provider(NamespacedResource, MTV):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             self.res.update({
                 "spec": {
                     "type": self.provider_type,
