@@ -31,7 +31,7 @@ class ResourceQuota(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not self.hard:
                 raise MissingRequiredArgumentError(argument="hard")
 
