@@ -44,7 +44,7 @@ class RoleBinding(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             subjects = {}
             if self.subjects_kind:
                 subjects["kind"] = self.subjects_kind
